# SPOLIN

This is a ParlAI Teacher for the dataset [SPOLIN](https://justin-cho.com/spolin), which is the dataset from [_Grounding Conversations with Improvised Dialogues_](https://aclanthology.org/2020.acl-main.218/) (ACL 2020)

The teacher loads data from the official Github repo at https://github.com/wise-east/spolin.

Please check out the paper and the repo for details about the dataset. If there are any questions, please reach out to hd.justincho at gmail dot com.

If you use this data, please consider citing our ACL 2020 paper:
```
@inproceedings{cho2020spolin,
    title={Grounding Conversations with Improvised Dialogues},
    author={Cho, Hyundong and May, Jonathan},
    booktitle ={Proceedings of the 58th Annual Meeting of the Association for Computational Linguistics},
    publisher = {Association for Computational Linguistics},
    location =  {Seattle, Washington, USA},
    year={2020}
}
```
